==> piwigo-2.1.6.zip: piwigo/plugins/c13y_upgrade/language/lv_LV/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

// --------- Starting below: New or revised $lang ---- from Butterfly (1.8)
$lang['c13y_upgrade_no_anomaly'] = 'Pēc aplikācijas uzlabojuma nav novērotas nekādas anomālijas, "Check upgrades" spraudnis tika deaktivēts.';
$lang['c13y_dbl_email_user'] = 'Lietotāji ar vienādām e-pasta adresēm';
$lang['c13y_correction_dbl_email_user'] = 'Izdzēst dubultlietotājus';
$lang['c13y_obsolete_plugin'] = 'Novecojis spraudnis';
$lang['c13y_correction_obsolete_plugin'] = '"%s" spraudnis jau ir iekļauts šajā aplikācijas versijā un Jums tas ir jāatinstalē.';

?>

==> piwigo-2.3.3.zip: piwigo/plugins/c13y_upgrade/language/lv_LV/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

// --------- Starting below: New or revised $lang ---- from Butterfly (1.8)
$lang['c13y_upgrade_no_anomaly'] = 'Pēc aplikācijas uzlabojuma nav novērotas nekādas anomālijas, "Check upgrades" spraudnis tika deaktivēts.';
$lang['c13y_dbl_email_user'] = 'Lietotāji ar vienādām e-pasta adresēm';
$lang['c13y_correction_dbl_email_user'] = 'Izdzēst dubultlietotājus';
$lang['c13y_obsolete_plugin'] = 'Novecojis spraudnis';
$lang['c13y_correction_obsolete_plugin'] = '"%s" spraudnis jau ir iekļauts šajā aplikācijas versijā un Jums tas ir jāatinstalē.';

?>
